<?php

namespace backend\modules\reports\controllers;

use backend\modules\master\models\Product;
use backend\modules\reports\models\InventoryClosingStock;
use backend\modules\reports\models\PurchaseReportByProduct;
use backend\modules\reports\models\SaleReportByProduct;
use Mpdf\Mpdf;
use yii\data\ActiveDataProvider;
use yii\data\ArrayDataProvider;
use Yii;
use yii\db\Query;
use yii\helpers\ArrayHelper;


class InventoryClosingStockController extends \yii\web\Controller
{
    public function actionIndex()
    {
        $model = new InventoryClosingStock();
        $query = InventoryClosingStock::find();


        if(Yii::$app->request->get()){
            $model->load(Yii::$app->request->queryParams);
           $query->andFilterWhere(['product_id'=>$model->prod_name]);

            if($model->bar_code){
                $query->andFilterWhere(['barcode'=>$model->bar_code]);
            }
            if($model->status){
                if($model->status == 3){
                    $query->andFilterWhere(['<=','stock_unit',0]);
                }else if($model->status == 1){
                    $query->andFilterWhere(['>','stock_unit',1]);
                }else{

                }
            }
        }


        $dataProvider = new ActiveDataProvider([
            'query'=>$query,
        ]);
        return $this->render('index',[
            'dataProvider'=>$dataProvider,
            'model'=> $model, 
        ]);
    }
    public function actionProductdetails($searchTerm=null)
    {
        if(!$searchTerm)
            $product=Product::find()->limit(10)->all();
        else
            $product=Product::find()->where(["like","product_name",$searchTerm])->limit(10)->all();

        $productlist=ArrayHelper::map($product, 'id', 'product_name');
        return json_encode($productlist);
    }
    public function actionMonthlySummary($prod_id)
    {
         $current_month = date("m");
         if($current_month > 4){
             $from_year = date("Y");
             $from_date = $from_year. '-04-01';
         }else{
             $from_year = date("Y") -1;
             $from_date = $from_year. '-04-01';
         }
            $to_date = date("Y-m-d");
        $query = Yii::$app->db->createCommand("CALL monthly_inventory_products(:params_1,:params_2,:params_3)")
                             ->bindValue(':params_1',$prod_id)
                             ->bindValue(':params_2',$from_date )
                             ->bindValue(':params_3',$to_date)
                             ->queryAll();
        $dataProvider = new ArrayDataProvider([
            'allModels'=>$query,
        ]);
        $product = Product::find()->where(['id'=>$prod_id])->one();
        return $this->render('monthly-summary',[
            'dataProvider'=>$dataProvider,
            'from_date'=>$from_date,
            'to_date'=> $to_date,
            'product_name'=>$product->product_name
        ]);
    }
    public function actionStockQuery($prod_id,$print=null)
    {
        $model = new InventoryClosingStock();
        $query_1 = PurchaseReportByProduct::find()->where(['product_id'=>$prod_id]);
        if(Yii::$app->request->get()){
            $model->load(Yii::$app->request->queryParams);
            $query_1->andFilterWhere(['between','Date',$model->from_date,$model->to_date]);
        }
        $dataProvider_1 = new ActiveDataProvider([
            'query'=>$query_1
        ]);
        $query_2 = SaleReportByProduct::find()->where(['product_id'=> $prod_id]);
        if(Yii::$app->request->get()){
            $query_2->andFilterWhere(['between','Date',$model->from_date,$model->to_date]);
        }
        $dataProvider_2 = new ActiveDataProvider([
            'query'=>$query_2
        ]);
        $product = InventoryClosingStock::find()->where(['product_id'=>$prod_id])->one();
        if($print!=null)
        {
            $dataProvider_1->pagination = false;
            $dataProvider_2->pagination = false;
            $mpdf = new mPDF;
            $mpdf->showImageErrors = true;
            $mpdf->WriteHTML($this->renderPartial('/inventory-closing-stock/exportpdf', [
                'dataProvider_1' => $dataProvider_1,
                'dataProvider_2' => $dataProvider_2,
                'model'=>$model,
                'stock_unit' => $product->stock_unit,
                'product'=> $product->product_name,

            ]));
            $mpdf->Output('inventory-product-report.pdf', 'I');
        }

        return $this->render('stock-query',[
                 'dataProvider_1'=>$dataProvider_1,
                  'dataProvider_2'=> $dataProvider_2,
                    'model'=> $model,
                    'product'=> $product->product_name,
                     'stock_unit' => $product->stock_unit,
                      'product_id'=> $product->product_id
        ]);

    }
    public function actionExportPdf($prod_id)
    {
        $model = new InventoryClosingStock();
        $query_1 = PurchaseReportByProduct::find()->where(['product_id'=>$prod_id]);
        $dataProvider_1 = new ActiveDataProvider([
            'query'=>$query_1
        ]);
        $query_2 = SaleReportByProduct::find()->where(['product_id'=> $prod_id]);
        $dataProvider_2 = new ActiveDataProvider([
            'query'=>$query_2
        ]);
        $product = InventoryClosingStock::find()->where(['product_id'=>$prod_id])->one();
        $dataProvider_1->pagination = false;
        $dataProvider_2->pagination = false;
        $mpdf = new mPDF;
        $mpdf->WriteHTML($this->renderPartial('/inventory-closing-stock/exportpdf', [
            'dataProvider_1' => $dataProvider_1,
            'dataProvider_2' => $dataProvider_2,
            'model'=> $model,
            'stock_unit' => $product->stock_unit,
            'product'=> $product->product_name,
        ]));
        $mpdf->Output('Inventory-Product-Report.pdf', 'D');
    }


}
