<?php

namespace backend\modules\reports\controllers;

use backend\modules\reports\models\SaleReportByProduct;
use backend\modules\reports\models\SaleReportByProductSearch;
use backend\modules\master\models\Product;
use backend\modules\master\models\Customer;
use backend\modules\master\models\Vendor;
use common\models\User;
use backend\modules\master\models\AccountingTax;
use yii\data\ActiveDataProvider;
use yii\helpers\ArrayHelper;
use Mpdf\Mpdf;
use yii2tech\spreadsheet\Spreadsheet;
use Yii;
// use PHPExcel; 
// use PHPExcel_IOFactory;

class SaleReportByProductController extends \yii\web\Controller
{
    public function actionIndex($detailprint=null,$excel=null,$summaryexcel=null,$detail=null,$pdf=null)
    {   
        $model = new SaleReportByProduct();
        $searchModel = new SaleReportByProductSearch();
        $query =SaleReportByProduct::find();
        if(Yii::$app->request->get()){
            $searchModel->load(Yii::$app->request->queryParams);
            $query->andFilterWhere(['like', 'Executive', $searchModel->Executive])
                  ->andFilterWhere(['like', 'Description', $searchModel->Category])
                  ->andFilterWhere(['like', 'product_name', $searchModel->product_name])
                  ->andFilterWhere(['like', 'customer_type', $searchModel->customer_type])
                  ->andFilterWhere(['like', 'Particulars', $searchModel->Particulars])
                  ->andFilterWhere(['like', 'VendorDEALER', $searchModel->VendorDEALER]);
            if($searchModel->date_range){
                if($searchModel->date_range=='today'){
                $query->andFilterWhere(['like', 'Date', date('Y-m-d')]);
                }elseif($searchModel->date_range=='current_week') {
                    $query->andFilterWhere(['>=', 'Date',date('Y-m-d',strtotime('last monday')) ]);
                }elseif($searchModel->date_range=='current_month') {
                    $query->andFilterWhere(['>=', 'Date',date ('Y-m-d', strtotime ('first day of this month')) ]);
                }
                elseif($searchModel->date_range=='current_year') {
                    $query->andFilterWhere(['>=', 'Date',date('Y-m-d',strtotime(date('Y-01-01')))]);
                }elseif($searchModel->date_range=='custom'){

                    $query->andFilterWhere(['between', 'Date', $searchModel->from_date,$searchModel->to_date]);
                } 
            }


            if($searchModel->order_by){
                if($searchModel->order_by=='vasc'){
                 $query->orderBy(['CAST(VChNo as unsigned)' => SORT_ASC]);
                }elseif($searchModel->order_by=='vdsc'){
                    $query->orderBy(['CAST(VChNo as unsigned)' => SORT_DESC]);
                }elseif($searchModel->order_by=='ddsc'){
                    $query->orderBy(['Date' => SORT_DESC]);
                }elseif($searcactionIndexhModel->order_by=='dasc'){
                    $query->orderBy(['Date' => SORT_ASC]);
                }
            }
            if($searchModel->report_type){
                if($searchModel->report_type=='invoice'){
                    $query->andFilterWhere(['or',['converted_to' => 'Invoice'],['converted_to' => 'Receipt']]);
                }elseif($searchModel->report_type=='sale_order'){
                    $query->andFilterWhere(['converted_to' => 'SaleOrder']);
                }
            }

            if($searchModel->created_by){
                $query->andFilterWhere(['created_by' => $searchModel->created_by]);
            
        }
    }



        $dataProvider = new ActiveDataProvider([
            'query' => $query,
            // 'pagination' => false,

        ]);

        if($detailprint!=null)
        {
          $for = 'print';
          $this->actionExportPdf($dataProvider,$model,$for);
        }
        if($excel!=null && $detail!=null)
        {
            $this->actionExcelExport($dataProvider,$detail);
        }
        if($summaryexcel!=null)
        {
            $this->actionExcelExport($dataProvider);
        }
        if($pdf!=null)
        {
          $for = "pdf";
          $this->actionExportPdf($dataProvider,$model,$for);
        }

        return $this->render('index', [
            'searchModel'=>$searchModel,
            'model' => $model,
            'dataProvider' => $dataProvider,

        ]);
    }


    public function actionExportPdf($data=null,$model=null,$for=null)
    {
        $data->pagination = false;
        $mpdf = new mPDF;
        $mpdf->showImageErrors = true;
        $mpdf->WriteHTML($this->renderPartial('/sale-report-by-product/exportpdf', [
            'dataProvider' => $data,
            'model'=>$model,
        ]));
        if($for=='pdf')
        {
            $mpdf->Output('Sale_Report.pdf', 'D');
        }
        else
        {
            $mpdf->Output('Sale_Report.pdf', 'I');
        }        
    }
    public function actionProductdetails($searchTerm=null)
    {   
        if(!$searchTerm)
        $product=Product::find()->limit(10)->all();
        else
        $product=Product::find()->where(["like","product_name",$searchTerm])->limit(10)->all();

        $productlist=ArrayHelper::map($product, 'product_name', 'product_name');
        return json_encode($productlist);
    }
    public function actionCustomerdetails($searchTerm=null)
    {   
        if(!$searchTerm)
        $customer=Customer::find()->limit(10)->all();
        else
        $customer=Customer::find()->where(["like","business_name",$searchTerm])->limit(10)->all();

        $customerlist=ArrayHelper::map($customer, 'business_name', 'business_name');
        return json_encode($customerlist);
    }
    public function actionVendordetails($searchTerm=null)
    {   
        if(!$searchTerm)
        $customer=Vendor::find()->limit(10)->all();
        else
        $customer=Vendor::find()->where(["like","business_name",$searchTerm])->limit(10)->all();

        $customerlist=ArrayHelper::map($customer, 'business_name', 'business_name');
        return json_encode($customerlist);
    }
    
    public function actionExcelExport($data=null,$detail=null)
    {  
         
        if($data!=null){
            $dataProvider = $data; 
            $dataProvider->pagination = false;

       }
       else
       {
         $dataProvider = new ActiveDataProvider([
           'query' => SaleReportByProduct::find()->orderBy(['Date' => SORT_DESC]),
           'pagination'=>false,
       ]);
       }

        // $query=SaleReportByProduct::find()
        // ->orderby(['sale_order_id'=>SORT_DESC]);
        // $dataProvider = new ActiveDataProvider([
        //     'query' => $query,
        //     'pagination'=>false,
        // ]);
        // print_r($dataProvider->models);die();
        // header('Content-type: application/vnd.ms-excel');
        // header('Content-Disposition: attachment; filename="puechase-report-by-product.xlsx"');
        // header('Cache-Control: max-age=0');
        // header ('Expires: Mon, 26 Jul 1997 05:00:00 GMT');
        // header ('Last-Modified: '.gmdate('D, d M Y H:i:s').' GMT');
        // header ('Cache-Control: cache, must-revalidate');
        // header ('Pragma: public');
       $sub=0;$tot_discount=0;$amount=0;$tax_percentage=0;$quantity=0;$discount=0;$taxes=0;$discount=0;$subtotal=0;

 if (!empty($dataProvider->getModels())) {
    foreach ($dataProvider->getModels() as $key => $val) {
        if($val->ItemDiscount){
            if($val->discount_type=='%'){
              $discount=($val->GrossTotal*($val->ItemDiscount/100));
            }else if($val->discount_type=='FLAT'){
             $discount= $val->ItemDiscount;
            }else{
             $discount=0;
            }
        }
        $tot_discount+=$discount;
        $sub+=$val->GrossTotal-$discount;
        $subtotal=$val->GrossTotal-$discount;
        $gross_total=$val->GrossTotal;
        $total_tax=0;
            $tax=AccountingTax::find()->where(['in','accounting_tax_id',explode(',',$val->TaxAmount)])->select('tax_rate')->column();
            if($val->tax_included){
            foreach ($tax as $key => $row) {
            $total_tax+=$row;
            }
        }
       
            $amount+=$subtotal+($subtotal*($total_tax/100));
            $quantity+=$val->Qty;
            // if($val->discount_type=='%'){
            //     $discount+=($val->ItemDiscount/100)*$val->GrossTotal;
            // }elseif ($val->discount_type=='FLAT') {
            //     $discount+=$val->GrossTotal-$val->ItemDiscount;
            // }
            // $discount+=$val->GrossTotal-$val->gross_amount;
            // $discount+=$val->gross_amount-($val->GrossTotal);
            // print($tax);die();

            $taxes=$taxes+(($total_tax/100)*($subtotal));
    }

}    if($detail){
        $phpExcel = new \PHPExcel;
        $phpExcel->getDefaultStyle()->getFont()->setName('Calibri');
        $phpExcel->getActiveSheet()->getStyle('D1')->getAlignment()->setWrapText(true);
        // $phpExcel->getDefaultStyle()->getFont()->setSize(14);
        // $phpExcel ->getProperties()->setTitle("Vendor list");
        $phpExcel ->getProperties()->setDescription("Excel SpreadSheet in PHP");
        $writer = \PHPExcel_IOFactory::createWriter($phpExcel, "Excel2007");
        $sheet = $phpExcel ->getActiveSheet();
         
        // $sheet->setTitle('My product list');
        $sheet ->getCell('A1')->setValue('MOHAPATRA SCIENTIFIC PRIVATE LIMITED');
        $sheet ->getCell('A2')->setValue('');
        $sheet ->getCell('A3')->setValue('F2G/30, INDRADHANU MARKET, IRC VILLAGE,');
        $sheet ->getCell('A4')->setValue('BHUBANESWAR, Odisha');
        $sheet ->getCell('A5')->setValue('');
        $sheet ->getCell('A6')->setValue('Sale Report By Product');
        // Making headers text bold and larger
        $sheet->getStyle('A1:S1')->getFont()->setBold(true)->setSize(12);
        $sheet->getStyle('A2:S2')->getFont()->setSize(11);
        $sheet->getStyle('A3:S3')->getFont()->setSize(11);
        $sheet->getStyle('A4:S4')->getFont()->setSize(11);
        $sheet->getStyle('A5:S5')->getFont()->setSize(11);
        $sheet->getStyle('A6:S6')->getFont()->setBold(true)->setSize(11);

       
  
        $sheet->getColumnDimension('A')->setWidth(20);
        $sheet->getColumnDimension('B')->setWidth(40);
        $sheet->getColumnDimension('C')->setWidth(20);
        $sheet->getColumnDimension('D')->setWidth(40);
        $sheet->getColumnDimension('E')->setWidth(20);
        $sheet->getColumnDimension('F')->setWidth(40);
        $sheet->getColumnDimension('G')->setWidth(20);
        $sheet->getColumnDimension('H')->setWidth(20);
        $sheet->getColumnDimension('I')->setWidth(20);
        $sheet->getColumnDimension('J')->setWidth(10);
        $sheet->getColumnDimension('K')->setWidth(22);
        $sheet->getColumnDimension('L')->setWidth(22);
        $sheet->getColumnDimension('M')->setWidth(22);
        $sheet->getColumnDimension('N')->setWidth(20);
        $sheet->getColumnDimension('O')->setWidth(20);
        $sheet->getColumnDimension('P')->setWidth(20);
        $sheet->getColumnDimension('Q')->setWidth(20);
        $sheet->getColumnDimension('R')->setWidth(20);
        $sheet->getColumnDimension('S')->setWidth(20);
        $sheet->getColumnDimension('T')->setWidth(20);
        $sheet->getColumnDimension('U')->setWidth(20);

        $sheet->getStyle('C')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);
        $sheet->getStyle('F')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);
        $sheet->getStyle('G')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);
        $sheet->getStyle('O')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);
        // $sheet->getStyle('C')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);
        // $sheet->getStyle('C')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);
        // $sheet->getStyle('C')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);
        // $sheet->getStyle('C')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);
       
  
        $sheet->mergeCells('A1:S1');
        $sheet->mergeCells('A2:S2');
        $sheet->mergeCells('A3:S3');
        $sheet->mergeCells('A4:S4');
        $sheet->mergeCells('A5:S5');
        $sheet->mergeCells('A6:S6');
  
      $sheet->setCellValue('A7',  'Date');
      $sheet->setCellValue('B7',  'Particulars');
      $sheet->setCellValue('C7',  'VCH No#');
      $sheet->setCellValue('D7',  'Product');
      $sheet->setCellValue('E7',  'Product Code');
      $sheet->setCellValue('F7',  'Description');
      $sheet->setCellValue('G7',  'Category');
      $sheet->setCellValue('H7',  'GST No');
      $sheet->setCellValue('I7',  'Qty');
      $sheet->setCellValue('J7',  'Rate/Basic');
      $sheet->setCellValue('K7',  'Item Discount');
      $sheet->setCellValue('L7',  'Gross Total ');
      $sheet->setCellValue('M7',  'Tax Amount');
      $sheet->setCellValue('N7',  'Charges / Roundof / Discount');
      $sheet->setCellValue('O7',  'Net Amount');
      $sheet->setCellValue('P7',  'Sales');
      $sheet->setCellValue('Q7',  'Executive');
      $sheet->setCellValue('R7',  'User');
      $sheet->setCellValue('S7',  'Vendor');
      $sheet->setCellValue('T7',  'Cost');
      $sheet->setCellValue('U7',  'Profit/loss');
      $row=8;
      $total_tax=0;
      $discount=0;
      $discount=0;$subtotal=0;
      $total_tax=0;
      $taxg = 0;
    //   $style = array(
    //     'alignment' => array(
    //         'horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_CENTER,
    //     )
    // );
      foreach ($dataProvider->models as $model) {
          
        // $sheet->getDefaultStyle()->applyFromArray($style);
        $sheet->getStyle('D'.$row)->getAlignment()->setWrapText(true);
        $sheet->getStyle('S'.$row)->getAlignment()->setWrapText(true);

        $sheet->getRowDimension($row)->setRowHeight(30);
        if($model->ItemDiscount){
            if($model->discount_type=='%'){
              $discount=($model->GrossTotal*($model->ItemDiscount/100));
            }else if($model->discount_type=='FLAT'){
             $discount= $model->ItemDiscount;
            }else{
             $discount=0;
            }
        }
               
                    $subtotal=$model->GrossTotal-$discount;
                    //$tax=AccountingTax::find()->where(['in','accounting_tax_id',explode(',',$model->TaxAmount)])->select('tax_rate')->column();
	 		$tax=AccountingTax::find()->where(['=','accounting_tax_id',$model->TaxAmount])->select('tax_rate')->column();
                    // print_r(($tax[0]));die();
                   // $total_tax=$tax[0];
		    if(!empty( $tax )){
                    $total_tax= $tax[0];
                    }
                    else{
                        $total_tax=0;
                    }
                    if($model->tax_included)
                    {
                        $taxg=round(($total_tax/100)*$subtotal,2);
                    }else{
                        $taxg=0;
                    }
                    // $taxg=$total_tax?round(($total_tax/100)*$subtotal,2):'';
                    // $taxg=0;

        //         $tax=AccountingTax::find()->where(['in','accounting_tax_id',explode(',',$model->TaxAmount)])->select('tax_rate')->column();
        //         foreach ($tax as $key => $row) {
        //         $total_tax+=$row;
        //         }
               $net=number_format($model->gross_amount, 2);

               $user = User::find()->where(['id'=>$model->created_by])->one();
                       
               $profit=$model->gross_amount-$model->purchase_price;
      
      $sheet->setCellValue('A' . $row,  date('F j Y', strtotime($model->Date)));
      $sheet->setCellValue('B' . $row,  $model->Particulars);
      $sheet->setCellValue('C' . $row,  $model->VChNo);    
      $sheet->setCellValue('D' . $row,  $model->product_name); 
      $sheet->setCellValue('E' . $row,  ''); 
      $sheet->setCellValue('F' . $row,  $model->Description); 
      $sheet->setCellValue('G' . $row,  $model->Category); 
      $sheet->setCellValue('H' . $row,  $model->GSTNo); 
      $sheet->setCellValue('I' . $row,  $model->Qty); 
      $sheet->setCellValue('J' . $row,  $model->Rate); 
      $sheet->setCellValue('K' . $row,  (string)$discount); 
      $sheet->setCellValue('L' . $row,  (string)($model->GrossTotal-$discount)); 
      $sheet->setCellValue('M' . $row,  (string)$taxg); 
      $sheet->setCellValue('N' . $row,  '0'); 
      $sheet->setCellValue('O' . $row,  number_format($model->gross_amount, 2)); 
      $sheet->setCellValue('P' . $row,  'Sales - Taxable'); 
      $sheet->setCellValue('Q' . $row,  $model->Executive); 
      $sheet->setCellValue('R' . $row,  $user->username); 
      $sheet->setCellValue('S' . $row,  $model->VendorDEALER);
      $sheet->setCellValue('T' . $row,  $model->purchase_price); 
      $sheet->setCellValue('U' . $row,  (string)$profit); 

      $row++;   
     } 
     $sheet->setCellValue('B' . $row, 'Total(Rs)');
     
     $sheet->setCellValue('I' . $row,  (string)$quantity); 
     $sheet->setCellValue('J' . $row,  '-'); 
     $sheet->setCellValue('K' . $row,  (string)$tot_discount); 
     $sheet->setCellValue('L' . $row,  number_format($sub)); 
     $sheet->setCellValue('M' . $row,  (string)$taxes); 
     $sheet->setCellValue('N' . $row,  '0'); 
     $sheet->setCellValue('O' . $row,  number_format($amount,2)); 

     $sheet->getStyle('B'.$row)->getFont()->setBold(true)->setSize(11);
     $sheet->getStyle('I'.$row)->getFont()->setBold(true)->setSize(11);
     $sheet->getStyle('J'.$row)->getFont()->setBold(true)->setSize(11);
     $sheet->getStyle('K'.$row)->getFont()->setBold(true)->setSize(11);
     $sheet->getStyle('L'.$row)->getFont()->setBold(true)->setSize(11);
     $sheet->getStyle('M'.$row)->getFont()->setBold(true)->setSize(11);
     $sheet->getStyle('N'.$row)->getFont()->setBold(true)->setSize(11);
     $sheet->getStyle('O'.$row)->getFont()->setBold(true)->setSize(11);

    }else{
        $phpExcel = new \PHPExcel;
        $phpExcel->getDefaultStyle()->getFont()->setName('Calibri');
        $phpExcel->getActiveSheet()->getStyle('D1')->getAlignment()->setWrapText(true);
        // $phpExcel->getDefaultStyle()->getFont()->setSize(14);
        // $phpExcel ->getProperties()->setTitle("Vendor list");
        $phpExcel ->getProperties()->setDescription("Excel SpreadSheet in PHP");
        $writer = \PHPExcel_IOFactory::createWriter($phpExcel, "Excel2007");
        $sheet = $phpExcel ->getActiveSheet();
         
        // $sheet->setTitle('My product list');
        $sheet ->getCell('A1')->setValue('MOHAPATRA SCIENTIFIC PRIVATE LIMITED');
        $sheet ->getCell('A2')->setValue('');
        $sheet ->getCell('A3')->setValue('F2G/30, INDRADHANU MARKET, IRC VILLAGE,');
        $sheet ->getCell('A4')->setValue('BHUBANESWAR, Odisha');
        $sheet ->getCell('A5')->setValue('');
        $sheet ->getCell('A6')->setValue('Sale Report By Product');
        // Making headers text bold and larger
        $sheet->getStyle('A1:S1')->getFont()->setBold(true)->setSize(12);
        $sheet->getStyle('A2:S2')->getFont()->setSize(11);
        $sheet->getStyle('A3:S3')->getFont()->setSize(11);
        $sheet->getStyle('A4:S4')->getFont()->setSize(11);
        $sheet->getStyle('A5:S5')->getFont()->setSize(11);
        $sheet->getStyle('A6:S6')->getFont()->setBold(true)->setSize(11);

        $sheet->getColumnDimension('A')->setWidth(40);
        $sheet->getColumnDimension('B')->setWidth(30);
        $sheet->getColumnDimension('C')->setWidth(20);
        $sheet->getColumnDimension('D')->setWidth(20);
        
        $sheet->mergeCells('A1:S1');
        $sheet->mergeCells('A2:S2');
        $sheet->mergeCells('A3:S3');
        $sheet->mergeCells('A4:S4');
        $sheet->mergeCells('A5:S5');
        $sheet->mergeCells('A6:S6');

        $sheet->setCellValue('A7',  'Product');
        $sheet->setCellValue('B7',  'Prod Code');
        $sheet->setCellValue('C7',  'Qty');
        $sheet->setCellValue('D7',  'Rate/Basic');

        $row=8;
      $total_tax=0;
      $discount=0;
      $discount=0;$subtotal=0;
      $total_tax=0;
      $taxg = 0;
      $rate=0;
          //   $style = array(
    //     'alignment' => array(
    //         'horizontal' => PHPExcel_Style_Alignment::HORIZONTAL_CENTER,
    //     )
    // );
      foreach ($dataProvider->models as $model) {
          
        // $sheet->getDefaultStyle()->applyFromArray($style);
        $sheet->getStyle('D'.$row)->getAlignment()->setWrapText(true);
        $sheet->getStyle('S'.$row)->getAlignment()->setWrapText(true);

        $sheet->getRowDimension($row)->setRowHeight(30);
        if($model->ItemDiscount){
            if($model->discount_type=='%'){
              $discount=($model->GrossTotal*($model->ItemDiscount/100));
            }else if($model->discount_type=='FLAT'){
             $discount= $model->ItemDiscount;
            }else{
             $discount=0;
            }
        }
                    $rate+=$model->Rate;
                    $subtotal=$model->GrossTotal-$discount;
                   // $tax=AccountingTax::find()->where(['in','accounting_tax_id',explode(',',$model->TaxAmount)])->select('tax_rate')->column();
			$tax=AccountingTax::find()->where(['=','accounting_tax_id',$model->TaxAmount])->select('tax_rate')->column();
                    // print_r(($tax[0]));die();
                    //$total_tax=$tax[0];
			if(!empty( $tax )){
                    $total_tax= $tax[0];
                    }
                    else{
                        $total_tax=0;
                    }

                    if($model->tax_included)
                    {
                        $taxg=round(($total_tax/100)*$subtotal,2);
                    }else{
                        $taxg=0;
                    }
               
               $net=number_format($model->gross_amount, 2);

               $user = User::find()->where(['id'=>$model->created_by])->one();
                       
               $profit=$model->gross_amount-$model->purchase_price;
      
      $sheet->setCellValue('A' . $row,  $model->product_name);
      $sheet->setCellValue('B' . $row,  '');
      $sheet->setCellValue('C' . $row,  $model->Qty);    
      $sheet->setCellValue('D' . $row,  $model->Rate); 

      $row++;   
     } 
     $sheet->setCellValue('B' . $row, 'Total(Rs)');
     
     $sheet->setCellValue('C' . $row,  (string)$quantity); 
     $sheet->setCellValue('D' . $row,  (string)$rate); 

    //  $sheet->setCellValue('K' . $row,  (string)$tot_discount); 
    //  $sheet->setCellValue('L' . $row,  number_format($sub)); 
    //  $sheet->setCellValue('M' . $row,  (string)$taxes); 
    //  $sheet->setCellValue('N' . $row,  0); 
    //  $sheet->setCellValue('O' . $row,  number_format($amount,2)); 

     $sheet->getStyle('B'.$row)->getFont()->setBold(true)->setSize(11);
     $sheet->getStyle('D'.$row)->getFont()->setBold(true)->setSize(11);
    //  $sheet->getStyle('J'.$row)->getFont()->setBold(true)->setSize(11);
    //  $sheet->getStyle('K'.$row)->getFont()->setBold(true)->setSize(11);
    //  $sheet->getStyle('L'.$row)->getFont()->setBold(true)->setSize(11);
    //  $sheet->getStyle('M'.$row)->getFont()->setBold(true)->setSize(11);
    //  $sheet->getStyle('N'.$row)->getFont()->setBold(true)->setSize(11);
    //  $sheet->getStyle('O'.$row)->getFont()->setBold(true)->setSize(11);
    }

     ob_clean();
     ob_start();
     
      header('Content-type: application/vnd.ms-excel'); // It will be called file.xls  
      header('Content-Disposition: attachment; filename="sale-report-by-product.xls"'); // Write file to the browser 

   $writer->save('php://output');
   ob_flush();
   exit();

    }

}
