<?php

namespace backend\modules\reports\controllers;

use Yii;
use backend\modules\reports\models\VendorAgingReport;
use yii\helpers\ArrayHelper;
use yii\helpers\Json;
use yii\data\ActiveDataProvider;
use yii\data\ArrayDataProvider;
use common\models\User;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii2tech\spreadsheet\Spreadsheet;
use yii\filters\VerbFilter;
use yii\db\Query;
use Mpdf\Mpdf;

class VendorAgingReportController extends \yii\web\Controller
{
    public function actionIndex($print=null,$pdf=null,$excel=null,$detailprint=null)
    {
        $model = new VendorAgingReport();
        $query=VendorAgingReport::find();
        if($model->load(Yii::$app->request->get())){
            $query->andFilterWhere ( [ 'OR' ,
            [ 'like' , 'vendor_type' , $model->vendor_vtype ],
            [ 'like' , 'ledgerhead_id' , $model->vendor_vtype ],
        ] )
        ->andFilterWhere(['like', 'vendor_type', $model->type])
        ->andFilterWhere(['<', 'createdat', $model->to_date]);
        }
        if($model->records){
            if($model->records=='nonzero'){ 
                $query->andFilterWhere(['<>',   'total'  , 0]);
                     
                }
            
        }      

        $dataProvider = new ActiveDataProvider([
            'query'=>$query,
        ]);
        if($print!=null)
        {
            $for = 'print';
            $this->actionDetailedExport($dataProvider,$model,$for);
        }

         if($pdf!=null)
        {
            $for = 'pdf';
            $this->actionDetailedExport($dataProvider,$model,$for);
        }
        if($excel!=null)
        {
            $this->actionExcelVendoragingreport($dataProvider);
        }
        if($detailprint!=null)
        {
            $for = 'detailprint';
            $this->actionDetailedExport($dataProvider,$model,$for);
        }
        return $this->render('index', [
            'model' => $model,
            'dataProvider' => $dataProvider,
        ]);   
     }
     public  function actionExcelVendoragingreport($data=null)
     {
        $phpExcel = new \PHPExcel;
        $phpExcel ->getProperties()->setDescription("Excel SpreadSheet in PHP");
        $writer = \PHPExcel_IOFactory::createWriter($phpExcel, "Excel2007");
        $sheet = $phpExcel ->getActiveSheet();

        $sheet->getRowDimension('A1')->setRowHeight(35);
        $sheet ->getCell('A1')->setValue('Vendor Aging Report');
        $sheet->getStyle('A1')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);
        // Making headers text bold and larger
        $sheet->getStyle('A1:I1')->getFont()->setBold(true)->setSize(12);

      $sheet->getColumnDimension('A')->setWidth(20);
      $sheet->getColumnDimension('B')->setWidth(15);
      $sheet->getColumnDimension('C')->setWidth(15);
      $sheet->getColumnDimension('D')->setWidth(15);
      $sheet->getColumnDimension('E')->setWidth(15);
      $sheet->getColumnDimension('F')->setWidth(15);
      $sheet->getColumnDimension('G')->setWidth(15);
      $sheet->getColumnDimension('H')->setWidth(15);
      $sheet->getColumnDimension('I')->setWidth(15);

      $sheet->getStyle('A3')->getFont()->setBold(true);
      $sheet->getStyle('B3')->getFont()->setBold(true);
      $sheet->getStyle('C3')->getFont()->setBold(true);
      $sheet->getStyle('D3')->getFont()->setBold(true);
      $sheet->getStyle('E3')->getFont()->setBold(true);
      $sheet->getStyle('F3')->getFont()->setBold(true);
      $sheet->getStyle('G3')->getFont()->setBold(true);
      $sheet->getStyle('H3')->getFont()->setBold(true);
      $sheet->getStyle('I3')->getFont()->setBold(true);


      $sheet->mergeCells('A1:I1');
      $sheet->mergeCells('A2:I2');

      $sheet->setCellValue('A3',  'Vendor Name');
      $sheet->setCellValue('B3',  date('F  Y', strtotime('-0 month')));
      $sheet->setCellValue('C3',  date('F  Y', strtotime('-1 month')));
      $sheet->setCellValue('D3',  date('F  Y', strtotime('-2 month')));
      $sheet->setCellValue('E3',  date('F  Y', strtotime('-3 month')));
      $sheet->setCellValue('F3',  date('F  Y', strtotime('-4 month')));
      $sheet->setCellValue('G3',  date('F  Y', strtotime('-5 month')));
      $sheet->setCellValue('H3',  'Debit');
      $sheet->setCellValue('I3',  'Credit');
      $row=4;
      foreach ($data->models as $data) {

        $sheet->setCellValue('A' . $row,  $data->ledgerhead_id);
        $sheet->setCellValue('B' . $row,  $data->first_month);
        $sheet->setCellValue('C' . $row,  $data->second_month);
        $sheet->setCellValue('D' . $row,  $data->third_month);
        $sheet->setCellValue('E' . $row,  $data->fourth_month);
        $sheet->setCellValue('F' . $row,  $data->fifth_month);
        $sheet->setCellValue('G' . $row,  $data->sixth_month);

        $debit = $data->previous_months+$data->sixth_month+$data->fifth_month+$data->fourth_month+$data->third_month+$data->second_month+$data->first_month;
        if($debit>0)
        {
            $sheet->setCellValue('H' . $row,  $debit);
        }
        else
        {
            $sheet->setCellValue('H' . $row, 0);   
        }

        $credit = $data->previous_months+$data->sixth_month+$data->fifth_month+$data->fourth_month+$data->third_month+$data->second_month+$data->first_month;
        if($credit>0)
        {
            $sheet->setCellValue('I' . $row,  $credit);
        }
        else
        {
            $sheet->setCellValue('I' . $row,  0);
        }
        $row++;
      }


    ob_clean();
        ob_start();
        
         header('Content-type: application/vnd.ms-excel'); // It will be called file.xls  
         header('Content-Disposition: attachment; filename="vendoragingreport.xls"'); // Write file to the browser 

      $writer->save('php://output');
      ob_flush();
      exit();

     }
     public  function actionDetailedExport($data=null,$model=null,$for=null)
     {  
        if($for=='print')
        {
            $data->pagination = false;
            $mpdf = new mPDF;
            $mpdf->showImageErrors = true;
            $mpdf->WriteHTML($this->renderPartial('/vendor-aging-report/export', [
                'dataProvider' => $data,
                'model'=>$model,
            ]));
            $mpdf->Output('Vendor_aging_report.pdf', 'I');
        }
        else if($for=='pdf')
        {
            $data->pagination = false;
            $mpdf = new mPDF;
            $mpdf->showImageErrors = true;
            $mpdf->WriteHTML($this->renderPartial('/vendor-aging-report/export', [
                'dataProvider' => $data,
                'model'=>$model,
            ]));
            $mpdf->Output('Vendor_aging_report.pdf', 'D');
        }
        else
        {
            $data->pagination = false;
            $mpdf = new mPDF;
            $mpdf->showImageErrors = true;
            $mpdf->WriteHTML($this->renderPartial('/vendor-aging-report/detailed-export', [
                'dataProvider' => $data,
                'model'=>$model,
            ]));
            $mpdf->Output('Detailed-Purchase-vendor-ledger.pdf', 'I');
        }
     }


}
